r2rmd(file, out=paste(file, "md", sep=""), header=TRUE, extra)readLines.writeLines,
or NULL (no file written).---)
is to be parsed.##} treated as non-code.
Leading #} followed by other than \code{#} is code comment.
Leading #} after whitespace is code comment.
A newline is code when preceded and followed by code.The leading double hash ##} is trimmed for comment lines.
R markdown chunk start/end stuff is added for code chunks.
The argument extra adds chunk arguments, e.g.
extra=', eval=FALSE' etc. See R markdown website at
http://rmarkdown.rstudio.com/
Returns a character vector invisibly, and writes a file as a side effects
unless out=NULL in which case no file is written.
[object Object]
http://rmarkdown.rstudio.com/
(r2rmd(system.file("r2rmd_example.R", package="mefa4"),
out=NULL, extra=", eval=FALSE"))
manip
IO